# locked-out
A data persistent python cli with timers (to lock in), note taking and ascii art :] Auto opens terminal + runs on pc startup
<img width="1282" height="1048" alt="Screenshot 2026-02-26 192210" src="https://github.com/user-attachments/assets/86a74d64-0833-457a-8a88-c18a40457434" />
# Install
run the following command:
```
pip install lockedout
```
# Use 
```
run 'lockedout' in any folder, and add any of the following flags. Use no flags to print a similar help message to the following message.
  -h, --help           show this help message and exit
  -l, --lockin [DURATION]  Set a reminder to lock in in X minutes
  -n, --note '[NOTE]'    quick note! updates only to the last note. Use -n again to display the note.
  -a, --art [ART]        Change ASCII art to [bat,bird,cat,dolphin,whale,shark]
```
